# Generated by roxygen2: do not edit by hand

S3method(add_node,prepper)
S3method(apply_transform,concat_pre_processor)
S3method(apply_transform,pre_processor)
S3method(biplot,pca)
S3method(block_indices,multiblock_projector)
S3method(block_lengths,multiblock_projector)
S3method(bootstrap,effect_operator)
S3method(bootstrap,plsc)
S3method(classifier,discriminant_projector)
S3method(classifier,multiblock_biprojector)
S3method(classifier,projector)
S3method(coef,cca)
S3method(coef,composed_projector)
S3method(coef,cross_projector)
S3method(coef,multiblock_projector)
S3method(coef,projector)
S3method(components,projector)
S3method(effect,mixed_fit)
S3method(feature_importance,classifier)
S3method(fit,prepper)
S3method(fit_transform,prepper)
S3method(fresh,pre_processor)
S3method(fresh,prepper)
S3method(init_transform,pre_processor)
S3method(inverse_projection,composed_projector)
S3method(inverse_projection,cross_projector)
S3method(inverse_projection,projector)
S3method(inverse_projection,regress)
S3method(inverse_transform,concat_pre_processor)
S3method(inverse_transform,pre_processor)
S3method(is_fitted,concat_pre_processor)
S3method(is_fitted,pre_processor)
S3method(is_fitted,prepper)
S3method(is_orthogonal,projector)
S3method(nblocks,multiblock_projector)
S3method(ncomp,perm_test_effect_operator)
S3method(ncomp,projector)
S3method(partial_inverse_projection,cross_projector)
S3method(partial_inverse_projection,projector)
S3method(partial_inverse_projection,regress)
S3method(partial_project,composed_partial_projector)
S3method(partial_project,cross_projector)
S3method(partial_project,partial_projector)
S3method(partial_project,projector)
S3method(partial_projector,projector)
S3method(perm_ci,pca)
S3method(perm_test,cross_projector)
S3method(perm_test,discriminant_projector)
S3method(perm_test,effect_operator)
S3method(perm_test,multiblock_biprojector)
S3method(perm_test,multiblock_projector)
S3method(perm_test,pca)
S3method(perm_test,plsc)
S3method(predict,classifier)
S3method(predict,discriminant_projector)
S3method(predict,rf_classifier)
S3method(prep,prepper)
S3method(print,bi_projector)
S3method(print,bi_projector_union)
S3method(print,bootstrap_effect_operator_result)
S3method(print,bootstrap_pca_result)
S3method(print,bootstrap_plsc_result)
S3method(print,cca)
S3method(print,classifier)
S3method(print,composed_projector)
S3method(print,concat_pre_processor)
S3method(print,cross_projector)
S3method(print,discriminant_projector)
S3method(print,effect_operator)
S3method(print,mixed_fit)
S3method(print,multiblock_biprojector)
S3method(print,pca)
S3method(print,perm_test)
S3method(print,perm_test_effect_operator)
S3method(print,perm_test_pca)
S3method(print,perm_test_plsc)
S3method(print,plsc)
S3method(print,pre_processor)
S3method(print,prepper)
S3method(print,projector)
S3method(print,regress)
S3method(print,rf_classifier)
S3method(project,classifier)
S3method(project,composed_projector)
S3method(project,cross_projector)
S3method(project,nystrom_approx)
S3method(project,partial_projector)
S3method(project,projector)
S3method(project_block,multiblock_projector)
S3method(project_vars,bi_projector)
S3method(project_vars,regress)
S3method(reconstruct,bi_projector)
S3method(reconstruct,composed_projector)
S3method(reconstruct,effect_operator)
S3method(reconstruct,pca)
S3method(reconstruct,regress)
S3method(reconstruct_new,bi_projector)
S3method(reconstruct_new,projector)
S3method(reprocess,cca)
S3method(reprocess,cross_projector)
S3method(reprocess,nystrom_approx)
S3method(reprocess,partial_projector)
S3method(reprocess,projector)
S3method(residuals,bi_projector)
S3method(reverse_transform,concat_pre_processor)
S3method(reverse_transform,pre_processor)
S3method(rf_classifier,projector)
S3method(rotate,pca)
S3method(scores,bi_projector)
S3method(scores,cca)
S3method(scores,plsc)
S3method(screeplot,pca)
S3method(sdev,bi_projector)
S3method(shape,cross_projector)
S3method(shape,projector)
S3method(std_scores,svd)
S3method(summary,composed_projector)
S3method(summary,mixed_fit)
S3method(transfer,cca)
S3method(transfer,cross_projector)
S3method(transfer,default)
S3method(transform,concat_pre_processor)
S3method(transform,pre_processor)
S3method(truncate,bi_projector)
S3method(truncate,cca)
S3method(truncate,composed_projector)
S3method(truncate,effect_operator)
S3method(truncate,partial_projector)
S3method(truncate,pca)
S3method(truncate,projector)
S3method(variables_used,composed_projector)
S3method(vars_for_component,composed_projector)
export("%>>%")
export(add_node)
export(apply_rotation)
export(apply_transform)
export(bi_projector)
export(bi_projector_union)
export(block_indices)
export(block_lengths)
export(bootstrap)
export(bootstrap_pca)
export(bootstrap_plsc)
export(cPCAplus)
export(cca)
export(center)
export(classifier)
export(colscale)
export(components)
export(compose_partial_projector)
export(compose_projector)
export(concat_pre_processors)
export(cross_projector)
export(cv)
export(cv_generic)
export(discriminant_projector)
export(effect)
export(effect_operator)
export(feature_importance)
export(fit)
export(fit_transform)
export(fresh)
export(geneig)
export(group_means)
export(identity_basis)
export(init_transform)
export(inverse_projection)
export(inverse_transform)
export(measure_interblock_transfer_error)
export(measure_reconstruction_error)
export(mixed_regress)
export(multiblock_biprojector)
export(multiblock_projector)
export(nblocks)
export(ncomp)
export(nystrom_approx)
export(partial_inverse_projection)
export(partial_project)
export(partial_projector)
export(pass)
export(pca)
export(pca_outliers)
export(perm_ci)
export(perm_test)
export(plsc)
export(prep)
export(preprocess)
export(prinang)
export(principal_angles)
export(project)
export(project_block)
export(project_vars)
export(projector)
export(rank_score)
export(reconstruct)
export(reconstruct_new)
export(refit)
export(regress)
export(reprocess)
export(residualize)
export(residuals)
export(reverse_transform)
export(rf_classifier)
export(rotate)
export(scores)
export(screeplot)
export(sdev)
export(shape)
export(shared_pca)
export(standardize)
export(std_scores)
export(subspace_similarity)
export(supplied_basis)
export(svd_wrapper)
export(topk)
export(transfer)
export(transform)
export(transpose)
export(truncate)
export(variables_used)
export(vars_for_component)
import(chk)
importFrom(Matrix,Cholesky)
importFrom(Matrix,Diagonal)
importFrom(Matrix,colMeans)
importFrom(Matrix,crossprod)
importFrom(Matrix,forceSymmetric)
importFrom(Matrix,isSymmetric)
importFrom(Matrix,solve)
importFrom(Matrix,t)
importFrom(chk,chk_range)
importFrom(cli,cli_abort)
importFrom(geigen,geigen)
importFrom(methods,as)
importFrom(methods,is)
importFrom(rlang,.data)
importFrom(stats,coef)
importFrom(stats,coefficients)
importFrom(stats,cov)
importFrom(stats,lm.fit)
importFrom(stats,lsfit)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,prcomp)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,resid)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(tibble,tibble)
importFrom(utils,combn)
importFrom(utils,modifyList)
